Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(1006)

Unified Diff: dfvfs/serializer/serializer.py

Issue 329840043: [dfvfs] Made Unicode strings the default #204 and updated docstrings #182 (Closed)
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dfvfs/serializer/json_serializer.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dfvfs/serializer/serializer.py
diff --git a/dfvfs/serializer/serializer.py b/dfvfs/serializer/serializer.py
index ed64ca619c8da008b134b90eebb16091e04580e5..411d9353a069192cfe279afd2df4c4039fd3752b 100644
--- a/dfvfs/serializer/serializer.py
+++ b/dfvfs/serializer/serializer.py
@@ -1,6 +1,8 @@
# -*- coding: utf-8 -*-
"""The Virtual File System (VFS) serializer object interfaces."""
+from __future__ import unicode_literals
+
# Since abc does not seem to have an @abc.abstractclassmethod we're using
# @abc.abstractmethod instead and shutting up pylint about:
# E0213: Method should have "self" as first argument.
@@ -17,10 +19,10 @@ class PathSpecSerializer(object):
"""Reads a path specification from serialized form.
Args:
serialized: an object containing the serialized form.
onager 2017/07/18 14:49:34 specification
Joachim Metz 2017/07/18 18:39:55 Done.
Returns:
- A path specification (instance of PathSpec).
+ PathSpec: a path specification.
"""
@abc.abstractmethod
@@ -28,8 +30,8 @@ class PathSpecSerializer(object):
"""Writes a path specification to serialized form.
Args:
- path_spec: a path specification (instance of PathSpec).
+ path_spec (PathSpec): a path specification.
Returns:
An object containing the serialized form.
"""
« no previous file with comments | « dfvfs/serializer/json_serializer.py ('k') | no next file » | no next file with comments »
@@ -17,10 +19,10 @@ class PathSpecSerializer(object):
"""Reads a path specification from serialized form.
Args:
- serialized: an object containing the serialized form.
+ serialized (object): serialized form of the path specificaiton.
onager 2017/07/18 14:49:34 specification
Joachim Metz 2017/07/18 18:39:55 Done.
@@ -28,8 +30,8 @@ class PathSpecSerializer(object):
Returns:
- An object containing the serialized form.
+ object: serialized form of the path specification.
"""
« no previous file with comments | « dfvfs/serializer/json_serializer.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b